@@ -2,10 +2,48 @@
 package MyTest::TestClass::Hash;
 use strict;
 use warnings;
+no warnings qw( once void );
 
 our $USES_MITE = "Mite::Class";
 our $MITE_SHIM = "MyTest::Mite";
-our $MITE_VERSION = "0.009000";
+our $MITE_VERSION = "0.010008";
+# Mite keywords
+BEGIN {
+    my ( $SHIM, $CALLER ) = ( "MyTest::Mite", "MyTest::TestClass::Hash" );
+    ( *after, *around, *before, *extends, *has, *signature_for, *with ) = do {
+        package MyTest::Mite;
+        no warnings 'redefine';
+        (
+            sub { $SHIM->HANDLE_after( $CALLER, "class", @_ ) },
+            sub { $SHIM->HANDLE_around( $CALLER, "class", @_ ) },
+            sub { $SHIM->HANDLE_before( $CALLER, "class", @_ ) },
+            sub {},
+            sub { $SHIM->HANDLE_has( $CALLER, has => @_ ) },
+            sub { $SHIM->HANDLE_signature_for( $CALLER, "class", @_ ) },
+            sub { $SHIM->HANDLE_with( $CALLER, @_ ) },
+        );
+    };
+};
+
+# Gather metadata for constructor and destructor
+sub __META__ {
+    no strict 'refs';
+    my $class      = shift; $class = ref($class) || $class;
+    my $linear_isa = mro::get_linear_isa( $class );
+    return {
+        BUILD => [
+            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+            map { "$_\::BUILD" } reverse @$linear_isa
+        ],
+        DEMOLISH => [
+            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
+            map { "$_\::DEMOLISH" } @$linear_isa
+        ],
+        HAS_BUILDARGS => $class->can('BUILDARGS'),
+        HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
+    };
+}
+
 
 # Standard Moose/Moo-style constructor
 sub new {
@@ -16,8 +54,8 @@ sub new {
     my $no_build = delete $args->{__no_BUILD__};
 
     # Attribute attr (type: HashRef)
-    # has declaration, file lib/MyTest/TestClass/Hash.pm, line 41
-    do { my $value = exists( $args->{"attr"} ) ? $args->{"attr"} : {}; (ref($value) eq 'HASH') or MyTest::Mite::croak "Type check failed in constructor: %s should be %s", "attr", "HashRef"; $self->{"attr"} = $value; }; 
+    # has declaration, file lib/MyTest/TestClass/Hash.pm, line 42
+    do { my $value = exists( $args->{"attr"} ) ? $args->{"attr"} : $MyTest::TestClass::Hash::__attr_DEFAULT__->( $self ); (ref($value) eq 'HASH') or MyTest::Mite::croak "Type check failed in constructor: %s should be %s", "attr", "HashRef"; $self->{"attr"} = $value; }; 
 
 
     # Call BUILD methods
@@ -56,44 +94,10 @@ sub DESTROY {
     return;
 }
 
-# Gather metadata for constructor and destructor
-sub __META__ {
-    no strict 'refs';
-    no warnings 'once';
-    my $class      = shift; $class = ref($class) || $class;
-    my $linear_isa = mro::get_linear_isa( $class );
-    return {
-        BUILD => [
-            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-            map { "$_\::BUILD" } reverse @$linear_isa
-        ],
-        DEMOLISH => [
-            map { ( *{$_}{CODE} ) ? ( *{$_}{CODE} ) : () }
-            map { "$_\::DEMOLISH" } @$linear_isa
-        ],
-        HAS_BUILDARGS => $class->can('BUILDARGS'),
-        HAS_FOREIGNBUILDARGS => $class->can('FOREIGNBUILDARGS'),
-    };
-}
-
-# See UNIVERSAL
-sub DOES {
-    my ( $self, $role ) = @_;
-    our %DOES;
-    return $DOES{$role} if exists $DOES{$role};
-    return 1 if $role eq __PACKAGE__;
-    return $self->SUPER::DOES( $role );
-}
-
-# Alias for Moose/Moo-compatibility
-sub does {
-    shift->DOES( @_ );
-}
-
-my $__XS = !$ENV{MITE_PURE_PERL} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
+my $__XS = !$ENV{PERL_ONLY} && eval { require Class::XSAccessor; Class::XSAccessor->VERSION("1.19") };
 
 # Accessors for attr
-# has declaration, file lib/MyTest/TestClass/Hash.pm, line 41
+# has declaration, file lib/MyTest/TestClass/Hash.pm, line 42
 if ( $__XS ) {
     Class::XSAccessor->import(
         chained => 1,
@@ -106,5 +110,22 @@ else {
 sub _set_attr { @_ == 2 or MyTest::Mite::croak( 'Writer "_set_attr" usage: $self->_set_attr( $newvalue )' ); (ref($_[1]) eq 'HASH') or MyTest::Mite::croak( "Type check failed in %s: value should be %s", "writer", "HashRef" ); $_[0]{"attr"} = $_[1]; $_[0]; }
 
 
+# See UNIVERSAL
+sub DOES {
+    my ( $self, $role ) = @_;
+    our %DOES;
+    return $DOES{$role} if exists $DOES{$role};
+    return 1 if $role eq __PACKAGE__;
+    if ( $INC{'Moose/Util.pm'} and my $meta = Moose::Util::find_meta( ref $self or $self ) ) {
+        $meta->can( 'does_role' ) and $meta->does_role( $role ) and return 1;
+    }
+    return $self->SUPER::DOES( $role );
+}
+
+# Alias for Moose/Moo-compatibility
+sub does {
+    shift->DOES( @_ );
+}
+
 1;
 }
\ No newline at end of file
